@@ -6,7 +6,7 @@ MOJANG_API = "https://api.mojang.com"
 
 async def get_uuid(name):
 	async with aiohttp.ClientSession() as client:
-		async with client.get(f"{MOJANG_API}/users/profiles/minecraft/{name}") as response
+		async with client.get(f"{MOJANG_API}/users/profiles/minecraft/{name}") as response:
 			try:
 				json = response.json()
 				return json["id"]
