@@ -24,7 +24,7 @@ class get_player:
 		if not name == None or not uuid == None:
 			
 			if uuid == None:
-				uuid = get_uuid(name)
+				uuid = await get_uuid(name)
 
 		async with aiohttp.ClientSession() as client:
 			async with client.get(f"{HYPIXEL_API}/player?key={self.api}&uuid={uuid}") as response:
